summaryrefslogtreecommitdiff
path: root/src/fe-common
diff options
context:
space:
mode:
Diffstat (limited to 'src/fe-common')
-rw-r--r--src/fe-common/core/chat-completion.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/fe-common/core/chat-completion.c b/src/fe-common/core/chat-completion.c
index 9e1c6eca..c70f7e5b 100644
--- a/src/fe-common/core/chat-completion.c
+++ b/src/fe-common/core/chat-completion.c
@@ -953,7 +953,9 @@ static void event_text(const char *data, SERVER_REC *server, WI_ITEM_REC *item)
}
}
- /* use "--" just in case the nick contains '-' character */
+ /* the nick is quoted in case it contains '-' character. also
+ spaces should work too now :) Unquoter function also allows
+ '"' characters as long as the next character isn't space. */
str = g_strdup_printf(IS_CHANNEL(item) ? "-channel \"%s\" %s" :
IS_QUERY(item) ? "-nick \"%s\" %s" : "%s %s",
window_item_get_target(item), line);